@@ -8,6 +8,7 @@
 #define MAINWINDOW_H
 
 // Qt
+#include <QAction>
 #include <QExplicitlySharedDataPointer>
 #include <QPointer>
 #include <QUrl>
@@ -168,6 +169,9 @@ private Q_SLOTS:
 
     void applyKonsoleSettings();
 
+    // Ask the window manager to show this application window
+    void activationRequest(const QString &xdgActivationToken);
+
     void updateUseTransparency();
 
 public Q_SLOTS:
