@@ -8,28 +8,26 @@
 #include "config-konsole.h"
 
 // Own
-#include "ProcessInfo.h"
 #include "NullProcessInfo.h"
-#if !defined(Q_OS_WIN)
-    #include "UnixProcessInfo.h"
-#endif
+#include "ProcessInfo.h"
 #include "SSHProcessInfo.h"
+#include "UnixProcessInfo.h"
 
 // Unix
-#include <sys/socket.h>
-#include <netinet/in.h>
 #include <arpa/inet.h>
-#include <unistd.h>
+#include <cerrno>
+#include <netinet/in.h>
 #include <pwd.h>
 #include <sys/param.h>
-#include <cerrno>
+#include <sys/socket.h>
+#include <unistd.h>
 
 // Qt
 #include <QDir>
 #include <QFileInfo>
-#include <QTextStream>
-#include <QStringList>
 #include <QHostInfo>
+#include <QStringList>
+#include <QTextStream>
 
 // KDE
 #include <KConfigGroup>
@@ -47,36 +45,36 @@
 
 #if defined(Q_OS_FREEBSD) || defined(Q_OS_OPENBSD)
 #include <sys/types.h>
-#include <sys/user.h>
+
 #include <sys/syslimits.h>
-#   if defined(Q_OS_FREEBSD)
-#   include <libutil.h>
-#   include <sys/param.h>
-#   include <sys/queue.h>
-#   endif
+#include <sys/user.h>
+#if defined(Q_OS_FREEBSD)
+#include <libutil.h>
+#include <sys/param.h>
+#include <sys/queue.h>
+#endif
 #endif
 
 using namespace Konsole;
 
-ProcessInfo::ProcessInfo(int pid) :
-    _fields(ARGUMENTS)     // arguments
+ProcessInfo::ProcessInfo(int pid)
+    : _fields(ARGUMENTS) // arguments
     // are currently always valid,
     // they just return an empty
     // vector / map respectively
     // if no arguments
     // have been explicitly set
-    ,
-    _pid(pid),
-    _parentPid(0),
-    _foregroundPid(0),
-    _userId(0),
-    _lastError(NoError),
-    _name(QString()),
-    _userName(QString()),
-    _userHomeDir(QString()),
-    _currentDir(QString()),
-    _userNameRequired(true),
-    _arguments(QVector<QString>())
+    , _pid(pid)
+    , _parentPid(0)
+    , _foregroundPid(0)
+    , _userId(0)
+    , _lastError(NoError)
+    , _name(QString())
+    , _userName(QString())
+    , _userHomeDir(QString())
+    , _currentDir(QString())
+    , _userNameRequired(true)
+    , _arguments(QVector<QString>())
 {
 }
 
@@ -114,9 +112,9 @@ QString ProcessInfo::validCurrentDir() const
     return dir;
 }
 
-QSet<QString> ProcessInfo::_commonDirNames;
+QStringList ProcessInfo::_commonDirNames;
 
-QSet<QString> ProcessInfo::commonDirNames()
+QStringList ProcessInfo::commonDirNames()
 {
     static bool forTheFirstTime = true;
 
@@ -124,8 +122,8 @@ QSet<QString> ProcessInfo::commonDirNames()
         const KSharedConfigPtr &config = KSharedConfig::openConfig();
         const KConfigGroup &configGroup = config->group("ProcessInfo");
         // Need to make a local copy so the begin() and end() point to the same QList
-        const QStringList commonDirsList = configGroup.readEntry("CommonDirNames", QStringList());
-        _commonDirNames = QSet<QString>(commonDirsList.begin(), commonDirsList.end());
+        _commonDirNames = configGroup.readEntry("CommonDirNames", QStringList());
+        _commonDirNames.removeDuplicates();
 
         forTheFirstTime = false;
     }
@@ -135,26 +133,22 @@ QSet<QString> ProcessInfo::commonDirNames()
 
 QString ProcessInfo::formatShortDir(const QString &input) const
 {
-    if(input == QStringLiteral("/")) {
+    if (input == QLatin1Char('/')) {
         return QStringLiteral("/");
     }
 
     QString result;
 
-    const QStringList &parts = input.split(QDir::separator());
+    const QStringList parts = input.split(QDir::separator());
 
-    QSet<QString> dirNamesToShorten = commonDirNames();
-
-    QListIterator<QString> iter(parts);
-    iter.toBack();
+    QStringList dirNamesToShorten = commonDirNames();
 
     // go backwards through the list of the path's parts
     // adding abbreviations of common directory names
     // and stopping when we reach a dir name which is not
     // in the commonDirNames set
-    while (iter.hasPrevious()) {
-        const QString &part = iter.previous();
-
+    for (auto it = parts.crbegin(), endIt = parts.crend(); it != endIt; ++it) {
+        const QString &part = *it;
         if (dirNamesToShorten.contains(part)) {
             result.prepend(QDir::separator() + part[0]);
         } else {
@@ -327,8 +321,8 @@ void ProcessInfo::setFileError(QFile::FileError error)
 class LinuxProcessInfo : public UnixProcessInfo
 {
 public:
-    explicit LinuxProcessInfo(int pid) :
-        UnixProcessInfo(pid)
+    explicit LinuxProcessInfo(int pid)
+        : UnixProcessInfo(pid)
     {
     }
 
@@ -504,15 +498,15 @@ private:
 class FreeBSDProcessInfo : public UnixProcessInfo
 {
 public:
-    explicit FreeBSDProcessInfo(int pid) :
-        UnixProcessInfo(pid)
+    explicit FreeBSDProcessInfo(int pid)
+        : UnixProcessInfo(pid)
     {
     }
 
 protected:
     bool readCurrentDir(int pid) override
     {
-#if defined(HAVE_OS_DRAGONFLYBSD)
+#if HAVE_OS_DRAGONFLYBSD
         char buf[PATH_MAX];
         int managementInfoBase[4];
         size_t len;
@@ -570,14 +564,14 @@ private:
             return false;
         }
 
-        kInfoProc = new struct kinfo_proc [mibLength];
+        kInfoProc = new struct kinfo_proc[mibLength];
 
         if (sysctl(managementInfoBase, 4, kInfoProc, &mibLength, NULL, 0) == -1) {
-            delete [] kInfoProc;
+            delete[] kInfoProc;
             return false;
         }
 
-#if defined(HAVE_OS_DRAGONFLYBSD)
+#if HAVE_OS_DRAGONFLYBSD
         setName(QString::fromUtf8(kInfoProc->kp_comm));
         setPid(kInfoProc->kp_pid);
         setParentPid(kInfoProc->kp_ppid);
@@ -593,7 +587,7 @@ private:
 
         readUserName();
 
-        delete [] kInfoProc;
+        delete[] kInfoProc;
         return true;
     }
 
@@ -629,8 +623,8 @@ private:
 class OpenBSDProcessInfo : public UnixProcessInfo
 {
 public:
-    explicit OpenBSDProcessInfo(int pid) :
-        UnixProcessInfo(pid)
+    explicit OpenBSDProcessInfo(int pid)
+        : UnixProcessInfo(pid)
     {
     }
 
@@ -747,8 +741,8 @@ private:
 class MacProcessInfo : public UnixProcessInfo
 {
 public:
-    explicit MacProcessInfo(int pid) :
-        UnixProcessInfo(pid)
+    explicit MacProcessInfo(int pid)
+        : UnixProcessInfo(pid)
     {
     }
 
@@ -781,19 +775,18 @@ private:
         if (sysctl(managementInfoBase, 4, nullptr, &mibLength, nullptr, 0) == -1) {
             return false;
         } else {
-            kInfoProc = new struct kinfo_proc [mibLength];
+            kInfoProc = new struct kinfo_proc[mibLength];
             if (sysctl(managementInfoBase, 4, kInfoProc, &mibLength, nullptr, 0) == -1) {
-                delete [] kInfoProc;
+                delete[] kInfoProc;
                 return false;
             } else {
                 const QString deviceNumber = QString::fromUtf8(devname(((&kInfoProc->kp_eproc)->e_tdev), S_IFCHR));
-                const QString fullDeviceName = QStringLiteral("/dev/")
-                                               + deviceNumber.rightJustified(3, QLatin1Char('0'));
+                const QString fullDeviceName = QStringLiteral("/dev/") + deviceNumber.rightJustified(3, QLatin1Char('0'));
 
                 setParentPid(kInfoProc->kp_eproc.e_ppid);
                 setForegroundPid(kInfoProc->kp_eproc.e_pgid);
 
-                delete [] kInfoProc;
+                delete[] kInfoProc;
 
                 const QByteArray deviceName = fullDeviceName.toLatin1();
                 const char *ttyName = deviceName.data();
@@ -809,21 +802,19 @@ private:
                 managementInfoBase[3] = statInfo.st_rdev;
 
                 mibLength = 0;
-                if (sysctl(managementInfoBase, sizeof(managementInfoBase) / sizeof(int), nullptr,
-                           &mibLength, nullptr, 0) == -1) {
+                if (sysctl(managementInfoBase, sizeof(managementInfoBase) / sizeof(int), nullptr, &mibLength, nullptr, 0) == -1) {
                     return false;
                 }
 
-                kInfoProc = new struct kinfo_proc [mibLength];
-                if (sysctl(managementInfoBase, sizeof(managementInfoBase) / sizeof(int), kInfoProc,
-                           &mibLength, nullptr, 0) == -1) {
+                kInfoProc = new struct kinfo_proc[mibLength];
+                if (sysctl(managementInfoBase, sizeof(managementInfoBase) / sizeof(int), kInfoProc, &mibLength, nullptr, 0) == -1) {
                     return false;
                 }
 
                 // The foreground program is the first one
                 setName(QString::fromUtf8(kInfoProc->kp_proc.p_comm));
 
-                delete [] kInfoProc;
+                delete[] kInfoProc;
             }
             setPid(pid);
         }
@@ -852,8 +843,8 @@ private:
 class SolarisProcessInfo : public UnixProcessInfo
 {
 public:
-    explicit SolarisProcessInfo(int pid) :
-        UnixProcessInfo(pid)
+    explicit SolarisProcessInfo(int pid)
+        : UnixProcessInfo(pid)
     {
     }
 
