@@ -29,7 +29,8 @@
 #define MODE_Cursor 4
 #define MODE_NewLine 5
 #define MODE_AppScreen 6
-#define MODES_SCREEN 7
+#define MODE_SelectCursor 7
+#define MODES_SCREEN 8
 
 #define REPL_None 0
 #define REPL_PROMPT 1
@@ -148,6 +149,16 @@ public:
     void setCursorX(int x);
     /** Position the cursor at line @p y, column @p x. */
     void setCursorYX(int y, int x);
+
+    void initSelCursor();
+    int selCursorUp(int n);
+    int selCursorDown(int n);
+    int selCursorLeft(int n);
+    int selCursorRight(int n);
+
+    int selSetSelectionStart(int mode);
+    int selSetSelectionEnd(int mode);
+
     /**
      * Sets the margins for scrolling the screen.
      *
@@ -314,6 +325,7 @@ public:
      * @see Character::rendition
      */
     void setRendition(RenditionFlags rendition);
+    void setUnderlineType(int type);
     /**
      * Disables the given @p rendition flag.  Rendition flags control the appearance
      * of characters on the screen.
@@ -346,6 +358,13 @@ public:
      */
     void setDefaultRendition();
 
+    void setULColor(int space, int color);
+
+    CharacterColor const *ulColorTable() const
+    {
+        return _ulColors;
+    };
+
     /** Returns the column which the cursor is positioned at. */
     int getCursorX() const;
     /** Returns the line which the cursor is positioned on. */
@@ -547,7 +566,7 @@ public:
      *
      * @param enable true to apply the attribute to the current line or false to remove it
      */
-    void setLineProperty(LineProperty property, bool enable);
+    void setLineProperty(quint16 property, bool enable);
 
     /**
      * Set REPL mode (shell integration)
@@ -560,6 +579,7 @@ public:
      * REPL_OUTPUT
      */
     void setReplMode(int mode);
+    void setExitCode(int exitCode);
     /** Return true if semantic shell integration is in use. */
     bool hasRepl() const
     {
@@ -642,7 +662,7 @@ public:
         for (int i = 0; i < _lines; ++i) {
             const ImageLine &il = _screenLines[i];
             for (int j = 0; j < il.length(); ++j) {
-                if (il[j].rendition & RE_EXTENDED_CHAR) {
+                if (il[j].rendition.f.extended) {
                     result << il[j].character;
                 }
             }
@@ -797,10 +817,19 @@ private:
     int _cuX;
     int _cuY;
 
+    // select mode cursor location
+    int _selCuX;
+    int _selCuY;
+
     // cursor color and rendition info
     CharacterColor _currentForeground;
     CharacterColor _currentBackground;
-    RenditionFlags _currentRendition;
+    RenditionFlagsC _currentRendition;
+
+    CharacterColor _ulColors[15];
+    int _ulColorQueueStart;
+    int _ulColorQueueEnd;
+    int _currentULColor;
 
     // margins ----------------
     int _topMargin;
@@ -815,6 +844,7 @@ private:
     std::pair<int, int> _replModeEnd;
     std::pair<int, int> _replLastOutputStart;
     std::pair<int, int> _replLastOutputEnd;
+    int commandCounter = 0;
 
     // ----------------------------
 
@@ -829,7 +859,7 @@ private:
     // effective colors and rendition ------------
     CharacterColor _effectiveForeground; // These are derived from
     CharacterColor _effectiveBackground; // the cu_* variables above
-    RenditionFlags _effectiveRendition; // to speed up operation
+    RenditionFlagsC _effectiveRendition; // to speed up operation
 
     class SavedState
     {
@@ -838,7 +868,7 @@ private:
             : cursorColumn(0)
             , cursorLine(0)
             , originMode(0)
-            , rendition(0)
+            , rendition({0})
             , foreground(CharacterColor())
             , background(CharacterColor())
         {
@@ -847,7 +877,7 @@ private:
         int cursorColumn;
         int cursorLine;
         int originMode;
-        RenditionFlags rendition;
+        RenditionFlagsC rendition;
         CharacterColor foreground;
         CharacterColor background;
     };
