@@ -124,6 +124,14 @@ void ViewManager::setupActions()
     collection->addAction(QStringLiteral("split-view-top-bottom"), action);
     splitViewActions->addAction(action);
 
+    action = new QAction(this);
+    action->setIcon(QIcon::fromTheme(QStringLiteral("view-split-auto")));
+    action->setText(i18nc("@action:inmenu", "Split View Automatically"));
+    connect(action, &QAction::triggered, this, &ViewManager::splitAuto);
+    collection->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::Key_Asterisk));
+    collection->addAction(QStringLiteral("split-view-auto"), action);
+    splitViewActions->addAction(action);
+
     splitViewActions->addSeparator();
 
     action = new QAction(this);
@@ -280,6 +288,18 @@ void ViewManager::setupActions()
     connect(action, &QAction::triggered, this, &ViewManager::semanticSetupBash);
     _viewContainer->addAction(action);
 
+    action = new QAction(i18nc("@action Shortcut entry", "Toggle semantic hints display"), this);
+    collection->addAction(QStringLiteral("toggle-semantic-hints"), action);
+    collection->setDefaultShortcut(action, Qt::CTRL | Qt::ALT | Qt::Key_BracketLeft);
+    connect(action, &QAction::triggered, this, &ViewManager::toggleSemanticHints);
+    _viewContainer->addAction(action);
+
+    action = new QAction(i18nc("@action Shortcut entry", "Toggle line numbers display"), this);
+    collection->addAction(QStringLiteral("toggle-line-numbers"), action);
+    collection->setDefaultShortcut(action, Qt::CTRL | Qt::ALT | Qt::Key_Backslash);
+    connect(action, &QAction::triggered, this, &ViewManager::toggleLineNumbers);
+    _viewContainer->addAction(action);
+
     action = new QAction(this);
     action->setText(i18nc("@action:inmenu", "Equal size to all views"));
     collection->setDefaultShortcut(action, Konsole::ACCEL | Qt::SHIFT | Qt::Key_Backslash);
@@ -486,12 +506,44 @@ void ViewManager::semanticSetupBash()
     Q_ASSERT(activeSession);
 
     activeSession->sendTextToTerminal(QStringLiteral(R"(if [[ ! $PS1 =~ 133 ]] ; then
-        PS1='\[\e]133;L\a\]\[\e]133;A\a\]'$PS1'\[\e]133;B\a\]' ;
+        PS1='\[\e]133;L\a\]\[\e]133;D;$?\]\[\e]133;A\a\]'$PS1'\[\e]133;B\a\]' ;
         PS2='\[\e]133;A\a\]'$PS2'\[\e]133;B\a\]' ;
         PS0='\[\e]133;C\a\]' ; fi)"),
                                       QChar());
 }
 
+void ViewManager::toggleSemanticHints()
+{
+    int currentSessionId = currentSession();
+    Q_ASSERT(currentSessionId >= 0);
+    Session *activeSession = SessionManager::instance()->idToSession(currentSessionId);
+    Q_ASSERT(activeSession);
+    auto profile = SessionManager::instance()->sessionProfile(activeSession);
+
+    profile->setProperty(Profile::SemanticHints, (profile->semanticHints() + 1) % 3);
+
+    auto activeTerminalDisplay = _viewContainer->activeViewSplitter()->activeTerminalDisplay();
+    const char *names[3] = {"Never", "Sometimes", "Always"};
+    activeTerminalDisplay->showNotification(i18n("Semantic hints ") + i18n(names[profile->semanticHints()]));
+    activeTerminalDisplay->update();
+}
+
+void ViewManager::toggleLineNumbers()
+{
+    int currentSessionId = currentSession();
+    Q_ASSERT(currentSessionId >= 0);
+    Session *activeSession = SessionManager::instance()->idToSession(currentSessionId);
+    Q_ASSERT(activeSession);
+    auto profile = SessionManager::instance()->sessionProfile(activeSession);
+
+    profile->setProperty(Profile::LineNumbers, (profile->lineNumbers() + 1) % 3);
+
+    auto activeTerminalDisplay = _viewContainer->activeViewSplitter()->activeTerminalDisplay();
+    const char *names[3] = {"Never", "Sometimes", "Always"};
+    activeTerminalDisplay->showNotification(i18n("Line numbers ") + i18n(names[profile->lineNumbers()]));
+    activeTerminalDisplay->update();
+}
+
 QHash<TerminalDisplay *, Session *> ViewManager::forgetAll(ViewSplitter *splitter)
 {
     splitter->setParent(nullptr);
@@ -627,6 +679,18 @@ void ViewManager::splitTopBottom()
     splitView(Qt::Vertical);
 }
 
+void ViewManager::splitAuto()
+{
+    Qt::Orientation orientation;
+    auto activeTerminalDisplay = _viewContainer->activeViewSplitter()->activeTerminalDisplay();
+    if (activeTerminalDisplay->width() > activeTerminalDisplay->height()) {
+        orientation = Qt::Horizontal;
+    } else {
+        orientation = Qt::Vertical;
+    }
+    splitView(orientation);
+}
+
 void ViewManager::splitView(Qt::Orientation orientation)
 {
     int currentSessionId = currentSession();
@@ -1006,10 +1070,23 @@ QJsonObject saveSessionsRecurse(QSplitter *splitter)
 
 void ViewManager::saveLayoutFile()
 {
-    QFile file(QFileDialog::getSaveFileName(this->widget(), i18n("Save File"), QStringLiteral("~/"), i18n("Konsole View Layout (*.json)")));
+    QString fileName(QFileDialog::getSaveFileName(this->widget(),
+                                                  i18nc("@title:window", "Save Tab Layout"),
+                                                  QStringLiteral("~/"),
+                                                  i18nc("@item:inlistbox", "Konsole View Layout (*.json)")));
 
+    // User pressed cancel in dialog
+    if (fileName.isEmpty()) {
+        return;
+    }
+
+    if (!fileName.endsWith(QStringLiteral(".json"))) {
+        fileName.append(QStringLiteral(".json"));
+    }
+
+    QFile file(fileName);
     if (!file.open(QIODevice::WriteOnly | QIODevice::Text)) {
-        KMessageBox::sorry(this->widget(), i18n("A problem occurred when saving the Layout.\n%1", file.fileName()));
+        KMessageBox::error(this->widget(), i18nc("@label:textbox", "A problem occurred when saving the Layout.\n%1", file.fileName()));
     }
 
     QJsonObject jsonSplit = saveSessionsRecurse(_viewContainer->activeViewSplitter());
@@ -1062,10 +1139,15 @@ ViewSplitter *restoreSessionsSplitterRecurse(const QJsonObject &jsonSplitter, Vi
 } // namespace
 void ViewManager::loadLayout(QString file)
 {
+    // User pressed cancel in dialog
+    if (file.isEmpty()) {
+        return;
+    }
+
     QFile jsonFile(file);
 
     if (!jsonFile.open(QIODevice::ReadOnly | QIODevice::Text)) {
-        KMessageBox::sorry(this->widget(), i18n("A problem occurred when loading the Layout.\n%1", jsonFile.fileName()));
+        KMessageBox::error(this->widget(), i18nc("@label:textbox", "A problem occurred when loading the Layout.\n%1", jsonFile.fileName()));
     }
     auto json = QJsonDocument::fromJson(jsonFile.readAll());
     if (!json.isEmpty()) {
@@ -1075,7 +1157,10 @@ void ViewManager::loadLayout(QString file)
 }
 void ViewManager::loadLayoutFile()
 {
-    loadLayout(QFileDialog::getOpenFileName(this->widget(), i18n("Open File"), QStringLiteral("~/"), i18n("Konsole View Layout (*.json)")));
+    loadLayout(QFileDialog::getOpenFileName(this->widget(),
+                                            i18nc("@title:window", "Load Tab Layout"),
+                                            QStringLiteral("~/"),
+                                            i18nc("@item:inlistbox", "Konsole View Layout (*.json)")));
 }
 
 void ViewManager::restoreSessions(const KConfigGroup &group)
