@@ -1,20 +1,7 @@
 /*
-    Copyright 2008 by Robert Knight <robertknight@gmail.com>
+    SPDX-FileCopyrightText: 2008 Robert Knight <robertknight@gmail.com>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // Own
@@ -27,40 +14,40 @@
 
 using namespace Konsole;
 
-const ColorEntry CharacterColorTest::DefaultColorTable[TABLE_COLORS] = {
-    ColorEntry(0x00, 0x00, 0x00), // Dfore
-    ColorEntry(0xFF, 0xFF, 0xFF), // Dback
-    ColorEntry(0x00, 0x00, 0x00), // Black
-    ColorEntry(0xB2, 0x18, 0x18), // Red
-    ColorEntry(0x18, 0xB2, 0x18), // Green
-    ColorEntry(0xB2, 0x68, 0x18), // Yellow
-    ColorEntry(0x18, 0x18, 0xB2), // Blue
-    ColorEntry(0xB2, 0x18, 0xB2), // Magenta
-    ColorEntry(0x18, 0xB2, 0xB2), // Cyan
-    ColorEntry(0xB2, 0xB2, 0xB2), // White
+const QColor CharacterColorTest::DefaultColorTable[TABLE_COLORS] = {
+    QColor(0x00, 0x00, 0x00), // Dfore
+    QColor(0xFF, 0xFF, 0xFF), // Dback
+    QColor(0x00, 0x00, 0x00), // Black
+    QColor(0xB2, 0x18, 0x18), // Red
+    QColor(0x18, 0xB2, 0x18), // Green
+    QColor(0xB2, 0x68, 0x18), // Yellow
+    QColor(0x18, 0x18, 0xB2), // Blue
+    QColor(0xB2, 0x18, 0xB2), // Magenta
+    QColor(0x18, 0xB2, 0xB2), // Cyan
+    QColor(0xB2, 0xB2, 0xB2), // White
     // intensive versions
-    ColorEntry(0x00, 0x00, 0x00),
-    ColorEntry(0xFF, 0xFF, 0xFF),
-    ColorEntry(0x68, 0x68, 0x68),
-    ColorEntry(0xFF, 0x54, 0x54),
-    ColorEntry(0x54, 0xFF, 0x54),
-    ColorEntry(0xFF, 0xFF, 0x54),
-    ColorEntry(0x54, 0x54, 0xFF),
-    ColorEntry(0xFF, 0x54, 0xFF),
-    ColorEntry(0x54, 0xFF, 0xFF),
-    ColorEntry(0xFF, 0xFF, 0xFF),
+    QColor(0x00, 0x00, 0x00),
+    QColor(0xFF, 0xFF, 0xFF),
+    QColor(0x68, 0x68, 0x68),
+    QColor(0xFF, 0x54, 0x54),
+    QColor(0x54, 0xFF, 0x54),
+    QColor(0xFF, 0xFF, 0x54),
+    QColor(0x54, 0x54, 0xFF),
+    QColor(0xFF, 0x54, 0xFF),
+    QColor(0x54, 0xFF, 0xFF),
+    QColor(0xFF, 0xFF, 0xFF),
     // Here are faint intensities, which may not be good.
     // faint versions
-    ColorEntry(0x00, 0x00, 0x00),
-    ColorEntry(0xFF, 0xFF, 0xFF),
-    ColorEntry(0x00, 0x00, 0x00),
-    ColorEntry(0x65, 0x00, 0x00),
-    ColorEntry(0x00, 0x65, 0x00),
-    ColorEntry(0x65, 0x5E, 0x00),
-    ColorEntry(0x00, 0x00, 0x65),
-    ColorEntry(0x65, 0x00, 0x65),
-    ColorEntry(0x00, 0x65, 0x65),
-    ColorEntry(0x65, 0x65, 0x65)
+    QColor(0x00, 0x00, 0x00),
+    QColor(0xFF, 0xFF, 0xFF),
+    QColor(0x00, 0x00, 0x00),
+    QColor(0x65, 0x00, 0x00),
+    QColor(0x00, 0x65, 0x00),
+    QColor(0x65, 0x5E, 0x00),
+    QColor(0x00, 0x00, 0x65),
+    QColor(0x65, 0x00, 0x65),
+    QColor(0x00, 0x65, 0x65),
+    QColor(0x65, 0x65, 0x65),
 };
 
 void CharacterColorTest::init()
@@ -73,10 +60,10 @@ void CharacterColorTest::cleanup()
 
 void CharacterColorTest::testColorEntry()
 {
-    ColorEntry black = ColorEntry(0x00, 0x00, 0x00);
-    ColorEntry white = ColorEntry(0xFF, 0xFF, 0xFF);
-    ColorEntry red   = ColorEntry(0xB2, 0x18, 0x18);
-    ColorEntry green = ColorEntry(0x18, 0xB2, 0x18);
+    QColor black = QColor(0x00, 0x00, 0x00);
+    QColor white = QColor(0xFF, 0xFF, 0xFF);
+    QColor red = QColor(0xB2, 0x18, 0x18);
+    QColor green = QColor(0x18, 0xB2, 0x18);
 
     // Test operator== operator!=
     QCOMPARE(black == white, false);
@@ -88,13 +75,13 @@ void CharacterColorTest::testColorEntry()
     QCOMPARE(red != green, true);
 
     // Test operator=
-    ColorEntry tmpColorEntry;
+    QColor tmpColorEntry;
     tmpColorEntry = red;
     QCOMPARE(tmpColorEntry == red, true);
     QCOMPARE(red == tmpColorEntry, true);
 
-    // Test ColorEntry()
-    ColorEntry defaultColorEntry = ColorEntry();
+    // Test QColor()
+    QColor defaultColorEntry = QColor();
     QCOMPARE(defaultColorEntry != green, true);
     QCOMPARE(defaultColorEntry != black, true);
     QCOMPARE(defaultColorEntry.isValid(), false);
@@ -187,8 +174,8 @@ void CharacterColorTest::testColor256_data()
         const QString name = QStringLiteral("color256 color %1").arg(i);
         const auto u = i - 16;
         const auto color = QColor(((u / 36) % 6) != 0 ? (40 * ((u / 36) % 6) + 55) : 0,
-                      ((u / 6) % 6) != 0 ? (40 * ((u / 6) % 6) + 55) : 0,
-                      ((u / 1) % 6) != 0 ? (40 * ((u / 1) % 6) + 55) : 0);
+                                  ((u / 6) % 6) != 0 ? (40 * ((u / 6) % 6) + 55) : 0,
+                                  ((u / 1) % 6) != 0 ? (40 * ((u / 1) % 6) + 55) : 0);
         QTest::newRow(qPrintable(name)) << i << color;
     }
     for (int i = 232; i < 256; ++i) {
