@@ -99,6 +99,8 @@ ColorSchemeEditor::ColorSchemeEditor(QWidget *parent)
     connect(_ui->wallpaperHorizontalAnchorSlider, &QSlider::valueChanged, this, &Konsole::ColorSchemeEditor::horizontalAnchorChanged);
     connect(_ui->wallpaperVerticalAnchorSlider, &QSlider::valueChanged, this, &Konsole::ColorSchemeEditor::verticalAnchorChanged);
 
+    connect(_ui->wallpaperFlipType, (void(QComboBox::*)(int)) & QComboBox::currentIndexChanged, this, &Konsole::ColorSchemeEditor::flipTypeChanged);
+
     // color table
     _ui->colorTable->setColumnCount(4);
     _ui->colorTable->setRowCount(COLOR_TABLE_ROW_LENGTH);
@@ -196,19 +198,31 @@ void ColorSchemeEditor::setWallpaperOpacity(int percent)
     _ui->wallpaperTransparencyPercentLabel->setText(QStringLiteral("%1%").arg(percent));
 
     const qreal opacity = (100.0 - percent) / 100.0;
-    _colors->setWallpaper(_colors->wallpaper()->path(), _colors->wallpaper()->style(), _colors->wallpaper()->anchor(), opacity);
+    _colors->setWallpaper(_colors->wallpaper()->path(),
+                          _colors->wallpaper()->style(),
+                          _colors->wallpaper()->anchor(),
+                          opacity,
+                          _colors->wallpaper()->flipType());
 }
 
 void ColorSchemeEditor::wallpaperPathChanged(const QString &path)
 {
     if (path.isEmpty()) {
-        _colors->setWallpaper(path, _colors->wallpaper()->style(), _colors->wallpaper()->anchor(), _colors->wallpaper()->opacity());
+        _colors->setWallpaper(path,
+                              _colors->wallpaper()->style(),
+                              _colors->wallpaper()->anchor(),
+                              _colors->wallpaper()->opacity(),
+                              _colors->wallpaper()->flipType());
         enableWallpaperSettings(false);
     } else {
         QFileInfo i(path);
 
         if (i.exists() && i.isFile() && i.isReadable()) {
-            _colors->setWallpaper(path, _colors->wallpaper()->style(), _colors->wallpaper()->anchor(), _colors->wallpaper()->opacity());
+            _colors->setWallpaper(path,
+                                  _colors->wallpaper()->style(),
+                                  _colors->wallpaper()->anchor(),
+                                  _colors->wallpaper()->opacity(),
+                                  _colors->wallpaper()->flipType());
             enableWallpaperSettings(true);
         }
     }
@@ -216,14 +230,34 @@ void ColorSchemeEditor::wallpaperPathChanged(const QString &path)
 
 void ColorSchemeEditor::scalingTypeChanged(int styleIndex)
 {
+    const char *flipType = QMetaEnum::fromType<ColorSchemeWallpaper::FlipType>().valueToKey(_colors->wallpaper()->flipType());
     const char *style = QMetaEnum::fromType<ColorSchemeWallpaper::FillStyle>().valueToKey(styleIndex);
-    _colors->setWallpaper(_colors->wallpaper()->path(), QString::fromLatin1(style), _colors->wallpaper()->anchor(), _colors->wallpaper()->opacity());
+    _colors->setWallpaper(_colors->wallpaper()->path(),
+                          QString::fromLatin1(style),
+                          _colors->wallpaper()->anchor(),
+                          _colors->wallpaper()->opacity(),
+                          QString::fromLatin1(flipType));
+}
+
+void ColorSchemeEditor::flipTypeChanged(int flipTypeIndex)
+{
+    const char *fillStyle = QMetaEnum::fromType<ColorSchemeWallpaper::FillStyle>().valueToKey(_colors->wallpaper()->style());
+    const char *flipType = QMetaEnum::fromType<ColorSchemeWallpaper::FlipType>().valueToKey(flipTypeIndex);
+    _colors->setWallpaper(_colors->wallpaper()->path(),
+                          QString::fromLatin1(fillStyle),
+                          _colors->wallpaper()->anchor(),
+                          _colors->wallpaper()->opacity(),
+                          QString::fromLatin1(flipType));
 }
 
 void ColorSchemeEditor::horizontalAnchorChanged(int pos)
 {
     QPointF anch = _colors->wallpaper()->anchor();
-    _colors->setWallpaper(_colors->wallpaper()->path(), _colors->wallpaper()->style(), QPointF(pos / 2.0, anch.y()), _colors->wallpaper()->opacity());
+    _colors->setWallpaper(_colors->wallpaper()->path(),
+                          _colors->wallpaper()->style(),
+                          QPointF(pos / 2.0, anch.y()),
+                          _colors->wallpaper()->opacity(),
+                          _colors->wallpaper()->flipType());
     switch (pos) {
     case 2:
         _ui->wallpaperHorizontalAnchorPosition->setText(QString::fromLatin1("Right"));
@@ -241,7 +275,11 @@ void ColorSchemeEditor::horizontalAnchorChanged(int pos)
 void ColorSchemeEditor::verticalAnchorChanged(int pos)
 {
     QPointF anch = _colors->wallpaper()->anchor();
-    _colors->setWallpaper(_colors->wallpaper()->path(), _colors->wallpaper()->style(), QPointF(anch.x(), pos / 2.0), _colors->wallpaper()->opacity());
+    _colors->setWallpaper(_colors->wallpaper()->path(),
+                          _colors->wallpaper()->style(),
+                          QPointF(anch.x(), pos / 2.0),
+                          _colors->wallpaper()->opacity(),
+                          _colors->wallpaper()->flipType());
     switch (pos) {
     case 2:
         _ui->wallpaperVerticalAnchorPosition->setText(QString::fromLatin1("Bottom"));
@@ -323,6 +361,7 @@ void ColorSchemeEditor::setup(const std::shared_ptr<const ColorScheme> &scheme,
     int ay = qRound(scheme->wallpaper()->anchor().y() * 2.0);
     _ui->wallpaperPath->setText(scheme->wallpaper()->path());
     _ui->wallpaperScalingType->setCurrentIndex(scheme->wallpaper()->style());
+    _ui->wallpaperFlipType->setCurrentIndex(scheme->wallpaper()->flipType());
     _ui->wallpaperHorizontalAnchorSlider->setValue(ax);
     _ui->wallpaperVerticalAnchorSlider->setValue(ay);
     enableWallpaperSettings(!scheme->wallpaper()->isNull());
@@ -382,4 +421,5 @@ void ColorSchemeEditor::enableWallpaperSettings(bool enable)
     _ui->wallpaperVerticalAnchorSlider->setEnabled(enable);
     _ui->wallpaperTransparencySlider->setEnabled(enable);
     _ui->wallpaperScalingType->setEnabled(enable);
+    _ui->wallpaperFlipType->setEnabled(enable);
 }
