@@ -200,10 +200,8 @@ bool ColorSchemeManager::pathIsColorScheme(const QString &path)
 
 bool ColorSchemeManager::isColorSchemeDeletable(const QString &name)
 {
-    const QString path = findColorSchemePath(name);
-
-    QFileInfo fileInfo(path);
-    QFileInfo dirInfo = fileInfo.path();
+    QFileInfo fileInfo(findColorSchemePath(name));
+    QFileInfo dirInfo(fileInfo.path());
 
     return dirInfo.isWritable();
 }
