@@ -7,7 +7,12 @@
 
 #include "EscapeSequenceUrlFilterHotSpot.h"
 
+#include <kio_version.h>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+#include <KIO/JobUiDelegateFactory>
+#else
 #include <KIO/JobUiDelegate>
+#endif
 #include <KIO/OpenUrlJob>
 
 #include <QApplication>
@@ -31,6 +36,10 @@ void EscapeSequenceUrlHotSpot::activate(QObject *obj)
     Q_UNUSED(obj)
 
     auto *job = new KIO::OpenUrlJob(QUrl(_url));
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, QApplication::activeWindow()));
+#else
     job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, QApplication::activeWindow()));
+#endif
     job->start();
 }
