@@ -25,7 +25,12 @@
 #include <KIO/OpenUrlJob>
 
 #include <KFileItemListProperties>
+#include <kio_version.h>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+#include <KIO/JobUiDelegateFactory>
+#else
 #include <KIO/JobUiDelegate>
+#endif
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KShell>
@@ -52,7 +57,7 @@ FileFilterHotSpot::FileFilterHotSpot(int startLine,
     , _session(session)
     , _thumbnailFinished(false)
 {
-    setType(Link);
+    setType(File);
 }
 
 void FileFilterHotSpot::activate(QObject *)
@@ -127,7 +132,11 @@ void FileFilterHotSpot::activate(QObject *)
 void FileFilterHotSpot::openWithSysDefaultApp(const QString &filePath) const
 {
     auto *job = new KIO::OpenUrlJob(QUrl::fromLocalFile(filePath));
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, QApplication::activeWindow()));
+#else
     job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, QApplication::activeWindow()));
+#endif
     job->setRunExecutables(false); // Always open scripts, shell/python/perl... etc, as text
     job->start();
 }
@@ -156,9 +165,9 @@ void FileFilterHotSpot::openWithEditorFromProfile(const QString &fullCmd, const
     connect(job, &KJob::result, this, [this, path, job]() {
         if (job->error() != 0) {
             // TODO: use KMessageWidget (like the "terminal is read-only" message)
-            KMessageBox::sorry(QApplication::activeWindow(),
-                               i18n("Could not open file with the text editor specified in the profile settings;\n"
-                                    "it will be opened with the system default editor."));
+            KMessageBox::information(QApplication::activeWindow(),
+                                     i18n("Could not open file with the text editor specified in the profile settings;\n"
+                                          "it will be opened with the system default editor."));
 
             openWithSysDefaultApp(path);
         }
@@ -181,15 +190,17 @@ QList<QAction *> FileFilterHotSpot::actions()
 
 QList<QAction *> FileFilterHotSpot::setupMenu(QMenu *menu)
 {
+    if (!_menuActions)
+        _menuActions = new KFileItemActions;
     const QList<QAction *> currentActions = menu->actions();
 
     const KFileItem fileItem(QUrl::fromLocalFile(_filePath));
     const KFileItemList itemList({fileItem});
     const KFileItemListProperties itemProperties(itemList);
-    _menuActions.setParent(this);
-    _menuActions.setItemListProperties(itemProperties);
+    _menuActions->setParent(this);
+    _menuActions->setItemListProperties(itemProperties);
 #if KIO_VERSION < QT_VERSION_CHECK(5, 82, 0)
-    _menuActions.addOpenWithActionsTo(menu);
+    _menuActions->addOpenWithActionsTo(menu);
 
     // Here we added the actions to the last part of the menu, but we need to move them up.
     // TODO: As soon as addOpenWithActionsTo accepts a index, change this.
@@ -206,7 +217,7 @@ QList<QAction *> FileFilterHotSpot::setupMenu(QMenu *menu)
     menu->insertAction(firstAction, separator);
 #else
     const QList<QAction *> actionList = menu->actions();
-    _menuActions.insertOpenWithActionsTo(!actionList.isEmpty() ? actionList.at(0) : nullptr, menu, QStringList());
+    _menuActions->insertOpenWithActionsTo(!actionList.isEmpty() ? actionList.at(0) : nullptr, menu, QStringList());
 #endif
 
     QList<QAction *> addedActions = menu->actions();
