@@ -33,6 +33,7 @@ class TerminalDisplay;
  */
 class FileFilterHotSpot : public RegExpFilterHotSpot
 {
+    Q_OBJECT
 public:
     FileFilterHotSpot(int startLine, int startColumn, int endLine, int endColumn, const QStringList &capturedTexts, const QString &filePath, Session *session);
     ~FileFilterHotSpot() override;
@@ -46,6 +47,7 @@ public:
     QList<QAction *> setupMenu(QMenu *menu) override;
 
     KFileItem fileItem() const;
+
     void requestThumbnail(Qt::KeyboardModifiers modifiers, const QPoint &pos);
     void thumbnailRequested();
 
@@ -66,7 +68,10 @@ private:
     void showThumbnail(const KFileItem &item, const QPixmap &preview);
     QString _filePath;
     Session *_session = nullptr;
-    KFileItemActions _menuActions;
+
+    // This is a pointer for performance reasons
+    // constructing KFileItemActions is super expensive
+    KFileItemActions *_menuActions = nullptr;
 
     QPoint _eventPos;
     QPoint _thumbnailPos;
