@@ -30,10 +30,11 @@ public:
     void getCells(const int lineno, const int colno, const int count, Character res[]) const override;
     bool isWrappedLine(const int lineno) const override;
     LineProperty getLineProperty(const int lineno) const override;
+    void setLineProperty(const int lineno, LineProperty prop) override;
 
     void addCells(const Character a[], const int count) override;
     void addCellsMove(Character a[], const int count) override;
-    void addLine(const LineProperty lineProperty = 0) override;
+    void addLine(const LineProperty lineProperty = LineProperty()) override;
 
     // Modify history (do nothing here)
     void removeCells() override;
