@@ -38,7 +38,20 @@ void CompactHistoryScroll::addCells(const Character a[], const int count)
 
     // store the (biased) start of next line + default flag
     // the flag is later updated when addLine is called
-    _lineDatas.push_back({static_cast<unsigned int>(_cells.size() + _indexBias), LINE_DEFAULT});
+    _lineDatas.push_back({static_cast<unsigned int>(_cells.size() + _indexBias), LineProperty()});
+
+    if (_lineDatas.size() > _maxLineCount + 5) {
+        removeLinesFromTop(5);
+    }
+}
+
+void CompactHistoryScroll::addCellsMove(Character characters[], const int count)
+{
+    std::move(characters, characters + count, std::back_inserter(_cells));
+
+    // store the (biased) start of next line + default flag
+    // the flag is later updated when addLine is called
+    _lineDatas.push_back({static_cast<unsigned int>(_cells.size() + _indexBias), LineProperty()});
 
     if (_lineDatas.size() > _maxLineCount + 5) {
         removeLinesFromTop(5);
@@ -118,7 +131,7 @@ void CompactHistoryScroll::removeCells()
 bool CompactHistoryScroll::isWrappedLine(const int lineNumber) const
 {
     Q_ASSERT((size_t)lineNumber < _lineDatas.size());
-    return (_lineDatas.at(lineNumber).flag & LINE_WRAPPED) > 0;
+    return (_lineDatas.at(lineNumber).flag.flags.f.wrapped) > 0;
 }
 
 LineProperty CompactHistoryScroll::getLineProperty(const int lineNumber) const
@@ -127,7 +140,13 @@ LineProperty CompactHistoryScroll::getLineProperty(const int lineNumber) const
     return _lineDatas.at(lineNumber).flag;
 }
 
-int CompactHistoryScroll::reflowLines(const int columns)
+void CompactHistoryScroll::setLineProperty(const int lineNumber, LineProperty prop)
+{
+    Q_ASSERT((size_t)lineNumber < _lineDatas.size());
+    _lineDatas.at(lineNumber).flag = prop;
+}
+
+int CompactHistoryScroll::reflowLines(const int columns, std::map<int, int> *deltas)
 {
     std::vector<LineData> newLineData;
 
@@ -139,6 +158,8 @@ int CompactHistoryScroll::reflowLines(const int columns)
     };
 
     int currentPos = 0;
+    int newPos = 0;
+    int delta = 0;
     while (currentPos < getLines()) {
         int startLine = startOfLine(currentPos);
         int endLine = startOfLine(currentPos + 1);
@@ -151,12 +172,20 @@ int CompactHistoryScroll::reflowLines(const int columns)
         }
 
         // Now reflow the lines
-        while (reflowLineLen(startLine, endLine) > columns && !(lineProperty & (LINE_DOUBLEHEIGHT_BOTTOM | LINE_DOUBLEHEIGHT_TOP))) {
+        while (reflowLineLen(startLine, endLine) > columns && !(lineProperty.flags.f.doubleheight_bottom | lineProperty.flags.f.doubleheight_top)) {
             startLine += columns;
-            setNewLine(newLineData, startLine + _indexBias, lineProperty | LINE_WRAPPED);
+            lineProperty.flags.f.wrapped = 1;
+            setNewLine(newLineData, startLine + _indexBias, lineProperty);
+            newPos++;
         }
-        setNewLine(newLineData, endLine + _indexBias, lineProperty & ~LINE_WRAPPED);
+        lineProperty.flags.f.wrapped = 0;
+        setNewLine(newLineData, endLine + _indexBias, lineProperty);
         currentPos++;
+        newPos++;
+        if (deltas && delta != newPos - currentPos) {
+            (*deltas)[currentPos - getLines()] = newPos - currentPos - delta;
+            delta = newPos - currentPos;
+        }
     }
     _lineDatas = std::move(newLineData);
 
