@@ -28,10 +28,11 @@ public:
     void getCells(const int lineNumber, const int startColumn, const int count, Character buffer[]) const override;
     bool isWrappedLine(const int lineNumber) const override;
     LineProperty getLineProperty(const int lineNumber) const override;
+    void setLineProperty(const int lineno, LineProperty prop) override;
 
     void addCells(const Character a[], const int count) override;
     void addCellsMove(Character a[], const int count) override;
-    void addLine(const LineProperty lineProperty = 0) override;
+    void addLine(const LineProperty lineProperty = LineProperty()) override;
 
     void removeCells() override;
 
@@ -70,7 +71,7 @@ private:
      * The size of this buffer is the number of lines we have.
      */
     std::vector<LineData> _lineDatas;
-    unsigned int _indexBias;
+    unsigned int _indexBias = 0;
 
     /**
      * Max number of lines we can hold
