@@ -17,6 +17,7 @@
 #include <QStringList>
 #include <QVariant>
 
+#include <map>
 #include <vector>
 
 // Konsole
@@ -159,6 +160,14 @@ public:
          * text display
          */
         BidiRenderingEnabled,
+        /** (bool) If true, lines are always LTR. Otherwise, decided by
+         * first strong character as defined by the BiDi algorithm.
+         */
+        BidiLineLTR,
+        /** (bool) Specifies whether the table drawing characters will be
+         * considered strong LTR by the BiDi algorithm.
+         */
+        BidiTableDirOverride,
         /** (bool) Specifies whether text in terminal displays is allowed
          * to blink.
          */
@@ -362,10 +371,45 @@ public:
         /** (bool) If true, move cursor with Left/Right keys when mouse clicks in input area
          */
         SemanticInputClick,
+        /** (QFont) Emoji font override
+         */
+        EmojiFont,
+        /** When to show line numbers.
+         * 0 for Never, 1 when showing URL hints, 2 for always
+         */
+        LineNumbers,
+        /** When to show Red error bars
+         */
+        ErrorBars,
+        /** When to show Red error background
+         */
+        ErrorBackground,
+        /** When to show alternating gray bars
+         */
+        AlternatingBars,
+        /** When to show alternating background
+         */
+        AlternatingBackground,
+        /** Render some sequences of characters with a single drawText() call
+         */
+        WordMode,
+        /** Attribute changes breaks words
+         */
+        WordModeAttr,
+        /** Use word mode for ASCII characters
+         * Used for performance and ligatures
+         */
+        WordModeAscii,
+        /** Use word mode for Brahmic scripts
+         * Improves display when the font is not strictly monospace
+         */
+        WordModeBrahmic,
     };
 
     Q_ENUM(Property)
 
+    using PropertyMap = std::map<Property, QVariant>;
+
     /**
      * Constructs a new profile
      *
@@ -424,22 +468,48 @@ public:
 
     /** Sets the value of the specified @p property to @p value. */
     virtual void setProperty(Property p, const QVariant &value);
+
+    void setProperty(Property p, QVariant &&value);
+
+    /** Sets the Property/value pairs from @p map on this Profile */
+    void assignProperties(const PropertyMap &map);
+    void assignProperties(PropertyMap &&map);
+
     /** Returns true if the specified property has been set in this Profile
      * instance.
      */
     virtual bool isPropertySet(Property p) const;
 
     /** Returns a map of the properties set in this Profile instance. */
-    virtual QHash<Property, QVariant> setProperties() const;
+    virtual const PropertyMap &properties() const;
 
     /** Returns true if no properties have been set in this Profile instance. */
     bool isEmpty() const;
 
+    /**
+     * Clears all set properties in this profile. Afte calling this, isEmpty()
+     * will return true.
+     */
+    void clear()
+    {
+        _propertyValues.clear();
+    }
+
     /**
      * Returns true if this profile is the built-in profile.
      */
     bool isBuiltin() const;
 
+    /**
+     * Returns true if this profile is editable.
+     */
+    bool isEditable() const;
+
+    /**
+     * Returns true if this profile can be deleted.
+     */
+    bool isDeletable() const;
+
     /**
      * Returns true if this is a 'hidden' profile which should not be
      * displayed in menus or saved to disk.
@@ -550,6 +620,12 @@ public:
         return property<QFont>(Profile::Font);
     }
 
+    /** Convenience method for property<QFont>(Profile::EmojiFont) */
+    QFont emojiFont() const
+    {
+        return property<QFont>(Profile::EmojiFont);
+    }
+
     /** Convenience method for property<QString>(Profile::ColorScheme) */
     QString colorScheme() const
     {
@@ -580,6 +656,18 @@ public:
         return property<bool>(Profile::BidiRenderingEnabled);
     }
 
+    /** Convenience method for property<bool>(Profile::BidiLineLTR) */
+    bool bidiLineLTR() const
+    {
+        return property<bool>(Profile::BidiLineLTR);
+    }
+
+    /** Convenience method for property<bool>(Profile::BidiTableDirOverride) */
+    bool bidiTableDirOverride() const
+    {
+        return property<bool>(Profile::BidiTableDirOverride);
+    }
+
     /** Convenience method for property<bool>(Profile::LineSpacing) */
     int lineSpacing() const
     {
@@ -757,6 +845,11 @@ public:
         return property<int>(Profile::SemanticHints);
     }
 
+    int lineNumbers() const
+    {
+        return property<int>(Profile::LineNumbers);
+    }
+
     bool semanticUpDown() const
     {
         return property<bool>(Profile::SemanticUpDown);
@@ -795,7 +888,7 @@ private:
     // returns true if the property can be inherited
     static bool canInheritProperty(Property p);
 
-    QHash<Property, QVariant> _propertyValues;
+    PropertyMap _propertyValues;
     Ptr _parent;
 
     bool _hidden;
@@ -827,8 +920,9 @@ inline T Profile::property(Property p) const
 template<>
 inline QVariant Profile::property(Property p) const
 {
-    if (_propertyValues.contains(p)) {
-        return _propertyValues[p];
+    auto it = _propertyValues.find(p);
+    if (it != _propertyValues.end()) {
+        return it->second;
     } else if (_parent && canInheritProperty(p)) {
         return _parent->property<QVariant>(p);
     } else {
