@@ -9,8 +9,6 @@
 
 // Qt
 #include <QFileInfo>
-#include <QKeyEvent>
-#include <QStandardItem>
 #include <QStandardPaths>
 
 // Konsole
@@ -103,11 +101,10 @@ void ProfileSettings::tableSelectionChanged(const QItemSelection &selected)
     const auto profile = currentProfile();
     const bool isNotDefault = profile != ProfileManager::instance()->defaultProfile();
 
-    // See comment about isProfileWritable(profile) in editSelected()
-    editProfileButton->setEnabled(isProfileWritable(profile));
+    editProfileButton->setEnabled(profile && profile->isEditable());
 
     // Do not allow the current default profile of the session to be removed
-    deleteProfileButton->setEnabled(isNotDefault && isProfileDeletable(profile));
+    deleteProfileButton->setEnabled(profile && isNotDefault && profile->isDeletable());
 
     setAsDefaultButton->setEnabled(isNotDefault);
 }
@@ -132,10 +129,10 @@ void ProfileSettings::setSelectedAsDefault()
 
 void ProfileSettings::createProfile()
 {
-    auto newProfile = Profile::Ptr(new Profile(ProfileManager::instance()->fallbackProfile()));
+    auto newProfile = Profile::Ptr(new Profile(ProfileManager::instance()->builtinProfile()));
 
     // If a profile is selected, clone its properties, otherwise the
-    // the fallback profile properties will be used
+    // the built-in profile's properties will be used
     if (currentProfile()) {
         newProfile->clone(currentProfile(), true);
     }
@@ -156,10 +153,8 @@ void ProfileSettings::editSelected()
 {
     const auto profile = currentProfile();
 
-    // Read-only profiles, i.e. oens with .profile's that aren't writable
-    // for the user aren't editable, only clone-able by using the "New"
-    // button, this includes the Default/fallback profile, which is hardcoded.
-    if (!isProfileWritable(profile)) {
+    // Uneditable profiles can only be cloned using the "New" button.
+    if (!(profile && profile->isEditable())) {
         return;
     }
 
@@ -180,24 +175,3 @@ Profile::Ptr ProfileSettings::currentProfile() const
 
     return selection->selectedIndexes().at(ProfileModel::PROFILE).data(ProfileModel::ProfilePtrRole).value<Profile::Ptr>();
 }
-
-bool ProfileSettings::isProfileDeletable(Profile::Ptr profile) const
-{
-    if (!profile || profile->isFallback()) {
-        return false;
-    }
-
-    const QFileInfo fileInfo(profile->path());
-    return fileInfo.exists() && QFileInfo(fileInfo.path()).isWritable(); // To delete a file, parent dir must be writable
-}
-
-bool ProfileSettings::isProfileWritable(Profile::Ptr profile) const
-{
-    return profile && !profile->isFallback() // Default/fallback profile is hardcoded
-        && QFileInfo(profile->path()).isWritable();
-}
-
-void ProfileSettings::setShortcutEditorVisible(bool visible)
-{
-    profileListView->setColumnHidden(ProfileModel::SHORTCUT, !visible);
-}
