@@ -19,14 +19,12 @@ TemporaryFilesSettings::TemporaryFilesSettings(QWidget *aParent)
 
     const QString tempPath = QStandardPaths::writableLocation(QStandardPaths::TempLocation);
     QString cachePath = QStandardPaths::writableLocation(QStandardPaths::CacheLocation);
-#ifdef Q_OS_UNIX
     // Use "~" instead of full path. It looks nice and helps
     // in cases when home path is really long.
     const QString homePath = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
     if (cachePath.startsWith(homePath)) {
         cachePath.replace(0, homePath.length(), QStringLiteral("~"));
     }
-#endif
 
     // There's no way of doing this with strings placed in .ui file
     kcfg_scrollbackUseSystemLocation->setText(
