@@ -337,6 +337,7 @@ void TerminalPainter::drawContents(Character *image,
                 }
                 if (!printerFriendly && char_value.rendition.f.cursor) {
                     Character style = char_value;
+                    m_parentDisplay->setVisualCursorPosition(x);
 
                     if (style.rendition.f.selected) {
                         if (invertedRendition) {
@@ -1070,7 +1071,7 @@ void TerminalPainter::drawTextCharacters(QPainter &painter,
             }
         }
         characterColor = foregroundColor;
-        if (style.rendition.f.cursor != 0) {
+        if (style.rendition.f.cursor != 0 && !m_parentDisplay->cursorBlinking()) {
             updateCursorTextColor(backgroundColor, characterColor);
         }
         if (m_parentDisplay->filterChain()->showUrlHint()) {
