@@ -211,6 +211,8 @@ void EditProfileDialog::save()
 
     if (isNewProfile) {
         ProfileManager::instance()->addProfile(_profile);
+        // The profile exists now, no longer treat it as initial creation
+        _profileState = EditProfileDialog::ExistingProfile;
     }
 
     bool defaultChanged = _isDefault != _generalUi->setAsDefaultButton->isChecked();
@@ -1622,7 +1624,7 @@ void EditProfileDialog::setupScrollingPage(const Profile::Ptr &profile)
     auto scrollFullPage = profile->property<int>(Profile::ScrollFullPage);
 
     _scrollingUi->scrollHalfPage->setChecked(Enum::ScrollPageHalf == scrollFullPage);
-    connect(_scrollingUi->scrollHalfPage, &QPushButton::clicked, this, &EditProfileDialog::scrollFullPage);
+    connect(_scrollingUi->scrollHalfPage, &QPushButton::clicked, this, &EditProfileDialog::scrollHalfPage);
 
     _scrollingUi->scrollFullPage->setChecked(Enum::ScrollPageFull == scrollFullPage);
     connect(_scrollingUi->scrollFullPage, &QPushButton::clicked, this, &EditProfileDialog::scrollFullPage);
@@ -1873,6 +1875,10 @@ void EditProfileDialog::setupAdvancedPage(const Profile::Ptr &profile)
 #endif
             &Konsole::EditProfileDialog::setDefaultCodec);
 
+    connect(codecAction, &KCodecAction::defaultItemTriggered, this, [this] {
+        setDefaultCodec(QTextCodec::codecForLocale());
+    });
+
     _advancedUi->selectEncodingButton->setText(profile->defaultEncoding());
 
     _advancedUi->peekPrimaryWidget->setKeySequence(profile->peekPrimaryKeySequence());
