@@ -92,7 +92,6 @@ public:
      * and make it easy for them to change it.
      */
     void selectProfileName();
-    const Profile::Ptr lookupProfile() const;
 
 public Q_SLOTS:
     // reimplemented
@@ -100,9 +99,6 @@ public Q_SLOTS:
     // reimplemented
     void reject() override;
 
-protected:
-    bool eventFilter(QObject *watched, QEvent *event) override;
-
 private Q_SLOTS:
     QSize sizeHint() const override;
 
@@ -155,6 +151,9 @@ private Q_SLOTS:
     void terminalMarginChanged(int margin);
     void lineSpacingChanged(int);
     void setTerminalCenter(bool enable);
+    void togglebidiRendering(bool);
+    void togglebidiTableDirOverride(bool);
+    void togglebidiLineLTR(bool);
 
 #if KNEWSTUFF_VERSION >= QT_VERSION_CHECK(5, 91, 0)
     void gotNewColorSchemes(const QList<KNSCore::EntryInternal> &changedEntries);
@@ -172,6 +171,7 @@ private Q_SLOTS:
     void colorSchemeSelected();
     void previewColorScheme(const QModelIndex &index);
     void showFontDialog();
+    void showEmojiFontDialog();
     void toggleMouseWheelZoom(bool enable);
 
     // scrolling page
@@ -214,15 +214,11 @@ private Q_SLOTS:
     // advanced page
     void toggleBlinkingText(bool);
     void toggleFlowControl(bool);
-    void togglebidiRendering(bool);
     void updateUrlHintsModifier(bool);
     void toggleReverseUrlHints(bool);
 
     void setDefaultCodec(QTextCodec *);
 
-    // apply the first previewed changes stored up by delayedPreview()
-    void delayedPreviewActivate();
-
     void setTextEditorCombo(const Profile::Ptr &profile);
 
     void toggleAllowLinkEscapeSequence(bool);
@@ -230,6 +226,11 @@ private Q_SLOTS:
 
     void peekPrimaryKeySequenceChanged();
 
+    void toggleWordMode(bool mode);
+    void toggleWordModeAttr(bool mode);
+    void toggleWordModeAscii(bool mode);
+    void toggleWordModeBrahmic(bool mode);
+
 private:
     Q_DISABLE_COPY(EditProfileDialog)
 
@@ -278,9 +279,8 @@ private:
     void showColorSchemeEditor(bool isNewScheme);
     void closeColorSchemeEditor();
 
-    void preview(int property, const QVariant &value);
-    void delayedPreview(int property, const QVariant &value);
-    void unpreview(int property);
+    void preview(Profile::Property prop, const QVariant &value);
+    void unpreview(Profile::Property prop);
     void unpreviewAll();
     void enableIfNonEmptySelection(QWidget *widget, QItemSelectionModel *selectionModel);
 
@@ -288,15 +288,15 @@ private:
     void updateTransparencyWarning();
 
     void updateFontPreview(QFont font);
+    void updateEmojiFontPreview(QFont font);
 
     // Update _tempProfile in a way of respecting the apply button.
     // When used with some previewed property, this method should
     // always come after the preview operation.
     void updateTempProfileProperty(Profile::Property, const QVariant &value);
 
-    // helper method for creating an empty & hidden profile and assigning
-    // it to _tempProfile.
-    void createTempProfile();
+    // helper method for clearing all _tempProfile properties and marking it hidden
+    void resetTempProfile();
 
     // Enable or disable apply button, used only within
     // updateTempProfileProperty() or when toggling the default profile.
@@ -351,14 +351,12 @@ private:
 
     bool _isDefault = false;
 
-    QHash<int, QVariant> _previewedProperties;
-
-    QHash<int, QVariant> _delayedPreviewProperties;
-    QTimer *_delayedPreviewTimer = nullptr;
+    Profile::PropertyMap _previewedProperties;
 
     ColorSchemeEditor *_colorDialog = nullptr;
     QDialogButtonBox *_buttonBox = nullptr;
     FontDialog *_fontDialog = nullptr;
+    FontDialog *_emojiFontDialog = nullptr;
 
     InitialProfileState _profileState = ExistingProfile;
 };
